### Viewing Glyphs

Font View is available in two viewing modes: Grid View and List View.
Toggle between the modes with the grid  and list  buttons in the top-left of the font window.

#### Grid View

In Grid View , the glyphs of the font are displayed in a grid of glyph cells.
The glyph outlines reflect the currently selected master.
Use the slider  in the bottom-right to control the cell size.
Large glyph cells display the glyph outlines, the glyph name, and the Unicode value of the glyph.
Small cells show only the outlines.

The Unicode value is shown in the bottom-right next to the glyph name.
By default, a small Unicode indicator  is displayed.
The Unicode indicator is replaced by a small rendering of the glyph set in the system font for CJK glyphs.
Enable “Display Unicode Value” in settings to show the full Unicode value.
Alternatively, select a glyph cell to show its Unicode values in the inspector located in the bottom-left of the window (see Unicode for details).

A warning  triangle in the top-right corner of a glyph cell indicates that the glyph has out-of-sync metrics keys.
A yellow note  indicates that the glyph has an annotation on the active master layer.
A black info i indicates that the glyph uses custom glyph properties.
A red top-left corner  in a glyph cell indicates that not all layers are compatible for interpolation.
A red ring with stroke  marks a non-exporting glyph.

A glyph cell displays its glyph and layer colors.

#### List View

Switch to List View by selecting the list  icon located in the top-left of the font window.
List View shows a table where each row corresponds to a glyph and each column to a glyph property.
Click a column header to sort by that column.
Click a header again to reverse the sort order.
Click and drag a column header to rearrange columns.
Control-click or right-click a header to hide or show columns.
See Glyph Properties for a description of all glyph properties.